==> james-project-3.7.6-source-release.zip: james-project/mailbox/api/src/main/java/org/apache/james/mailbox/quota/UserQuotaRootResolver.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.mailbox.quota;

import org.apache.james.core.Username;
import org.apache.james.mailbox.model.QuotaRoot;

public interface UserQuotaRootResolver extends QuotaRootResolver {

    QuotaRoot forUser(Username username);

    /**
     * When the username might not point to a user entity, and an extra translation step is required
     * for the quota root.
     */
    default QuotaRoot forMailAddress(Username username) {
        return forUser(username);
    }
}

==> james-project-3.9.0-source-release.zip: james-project/mailbox/api/src/main/java/org/apache/james/mailbox/quota/UserQuotaRootResolver.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.mailbox.quota;

import org.apache.james.core.Username;
import org.apache.james.mailbox.model.QuotaRoot;
import org.reactivestreams.Publisher;

public interface UserQuotaRootResolver extends QuotaRootResolver {

    QuotaRoot forUser(Username username);

    Publisher<QuotaRoot> listAllAccessibleQuotaRoots(Username username);

    /**
     * When the username might not point to a user entity, and an extra translation step is required
     * for the quota root.
     */
    default QuotaRoot forMailAddress(Username username) {
        return forUser(username);
    }
}
